@@ -18,4 +18,13 @@ from gt_lib.donchian_channel import donchian_channel
 from gt_lib.stochastic_rsi import stochastic_rsi
 from gt_lib.weighted_moving_average import wma
 from gt_lib.hull_moving_avg import hull_moving_avg
-from gt_lib.ichimoku_cloud import ichimoku_cloud
\ No newline at end of file
+from gt_lib.ichimoku_cloud import ichimoku_cloud
+
+mapping_dict = {
+                    'bollinger_band': ['upper', 'mean', 'low'],
+                    'donchian_channel': ['upper', 'mean', 'low'],
+                    'fractla': ['bearish', 'bullish'],
+                    'ichimoku_cloud': ['conv', 'base', 'span_a', 'span_b'],
+                    'macd': ['macd', 'signal', 'hist']
+    }
+
