@@ -9,6 +9,9 @@ import pandas as pd
 import numpy as np
 
 
-def atr(high_price, low_price, close_price, n=14):
+def atr(price_data, n=14):
+    price_data = price_data['<close>']
+    high_price, low_price, close_price = price_data['<high>'], price_data['<low>'], price_data['<close>']
     tr = np.amax(np.vstack(((high_price - low_price).to_numpy(), (abs(high_price - close_price)).to_numpy(), (abs(low_price - close_price)).to_numpy())).T, axis=1)
     return pd.Series(tr).rolling(n).mean().to_numpy()
+
