@@ -9,8 +9,10 @@ import pandas as pd
 import numpy as np
 
 
-def donchian_channel(high_price, low_price, n=14):
+def donchian_channel(price_data, n=14):
+    high_price = price_data['<high>']
+    low_price = price_data['<low>']
     uc = high_price.rolling(14).max()
     lc = low_price.rolling(14).min()
     mc = ((uc+lc)/2).to_numpy()
-    return uc.to_numpy(), lc.to_numpy(), mc
+    return uc.to_numpy(), mc, lc.to_numpy()
\ No newline at end of file
