@@ -9,7 +9,9 @@ import pandas as pd
 import numpy as np
 
 
-def ease_of_movement(high_price, low_price, volume):
+def ease_of_movement(price_data, volume):
+    high_price = price_data['<high>']
+    low_price = price_data['<low>']
     distance_moved = (high_price + low_price - high_price.shift(1) - low_price.shift(1))/2
     box_ratio = (volume / 1000) / (high_price - low_price)
     return (distance_moved/box_ratio).to_numpy()
