@@ -10,7 +10,8 @@ import numpy as np
 
 
 # ema calculator
-def ema(close_price, n=12):
+def ema(price_data, n=12):
+    close_price = price_data['<close>']
     if n >= 1:
         if not isinstance(n, int):
             print('n is not an int value')
