@@ -21,7 +21,9 @@ def bullish_fractal(x):
     return 0
 
 
-def fractal(high_price, low_price):
+def fractal(price_data):
+    high_price = price_data['<high>']
+    low_price = price_data['<low>']
     bearish_sig = high_price.rolling(5).apply(bearish_fractal, raw=False).to_numpy()
     bullish_sig = low_price.rolling(5).apply(bullish_fractal, raw=False).to_numpy()
     return bearish_sig, bullish_sig
