@@ -17,7 +17,11 @@ def loss(x):
     return ((x < 0) * x).sum()
 
 
-def mfi(high_price, low_price, close_price, volume, n=14):
+def mfi(price_data, n=14):
+    high_price = price_data['<high>']
+    low_price = price_data['<low>']
+    close_price = price_data['<close>']
+    volume = price_data['<volume>']
     typical_price = (high_price + low_price + close_price)/3
     money_flow = typical_price * volume
     mf_sign = np.where(typical_price > typical_price.shift(1), 1, -1)
