@@ -20,7 +20,9 @@ def reversal_cal(x):
         return 0
 
 
-def reversal(close_price, open_price):
+def reversal(price_data):
+    close_price = price_data['<close>']
+    open_price = price_data['<open>']
     c_o_signal = np.where(close_price - open_price > 0, 1, -1)
     reversal_signal = c_o_signal.rolling(4).apply(reversal_cal,)
     return reversal_signal
