@@ -10,7 +10,8 @@ import numpy as np
 
 
 # sma calculator
-def sma(close_price, n=12):
+def sma(price_data, n=12):
+    close_price = price_data['<close>']
     if n >= 1 and isinstance(n, int):
         return close_price.rolling(n).mean().to_numpy()
     else:
